{% load future %}

{% block title %}Timelines{% endblock %}

{% block timelines_class %}active{% endblock %}

{% block content %}

<div class="left-edge">
<h1>{{ TEAM_ACRONYM }} Timelines</h1>

<ul>
    {% for timeline in timelines %}
    <li><a href="{{ timeline.get_absolute_url }}">{{ timeline.title }}</a></li>
    {% endfor %}
</ul>
</div>

{% endblock %}

{% block sidebar %}
<div class="left-edge">
    <h2>Page Actions</h2>
    {% if user_can_add_timelines %}
    <ul class="button-list">
        <li><a class="btn btn-primary" href="{% url "admin:timelinejs_timeline_add" %}">Create New Timeline</a></li>
    </ul>
    {% endif %}
</div>
{% endblock %}
