/* Slovenian LANGUAGE SLOVENIAN
================================================== */typeof VMM!="undefined"&&(VMM.Language={lang:"sl",api:{wikipedia:"sl"},date:{month:["Januar","Februar","Marec","April","Maj","Junij","Julij","Avgust","September","Oktober","November","December"],month_abbr:["Jan.","Feb.","Marec","April","Maj","Junij","July","Avg.","Sept.","Okt.","Nov.","Dec."],day:["Nedelja","Ponedeljek","Torek","Sreda","Čertek","Petek","Sobota"],day_abbr:["Ned.","Pon.","Tor.","Sre.","Čet.","Pet.","Sob."]},dateformats:{year:"yyyy",month_short:"mmm",month:"mmmm yyyy",full_short:"d mmm",full:"d mmmm yyyy",time_no_seconds_short:"h:MM",time_no_seconds_small_date:"h:MM' 'd mmmm' 'yyyy",full_long:"d mmm yyyy 'ob' hh:MM",full_long_small_date:"hh:MM' d mmm yyyy"},messages:{loading_timeline:"Nalagam časovni trak... ",return_to_title:"Nazaj na naslov",expand_timeline:"Razširi časovni trak",contract_timeline:"Pokrči časovni trak",wikipedia:"Vir Wikipedija",loading_content:"Nalaganje vsebine",loading:"Nalaganje"}});